@@ -543,7 +543,8 @@ void ManualDiffHelpList::insertEntry(e_SrcSelector winIdx, LineRef firstLine, Li
             }
             if(i->firstLine(wIdx).isValid()) // Current item is not empty -> move it to the empty place
             {
-                std::swap(iEmpty, i);
+                std::swap(iEmpty->firstLine(wIdx), i->firstLine(wIdx));
+                std::swap(iEmpty->lastLine(wIdx), i->lastLine(wIdx));
                 ++iEmpty;
             }
         }
@@ -595,9 +596,9 @@ void DiffList::runDiff(const QVector<LineData>* p1, const qint32 index1, LineRef
     pp.setCurrent(0);
 
     clear();
-    if(p1 == nullptr || (*p1)[index1].getLine() == nullptr || p2 == nullptr || (*p2)[index2].getLine() == nullptr || size1 == 0 || size2 == 0)
+    if(p1 == nullptr || (*p1)[index1].getBuffer() == nullptr || p2 == nullptr || (*p2)[index2].getBuffer() == nullptr || size1 == 0 || size2 == 0)
     {
-        if(p1 != nullptr && p2 != nullptr && (*p1)[index1].getLine() == nullptr && (*p2)[index2].getLine() == nullptr && size1 == size2)
+        if(p1 != nullptr && p2 != nullptr && (*p1)[index1].getBuffer() == nullptr && (*p2)[index2].getBuffer() == nullptr && size1 == size2)
             push_back(Diff(size1, 0, 0));
         else
         {
@@ -606,13 +607,15 @@ void DiffList::runDiff(const QVector<LineData>* p1, const qint32 index1, LineRef
     }
     else
     {
+        assert(size1 < p1->size() && size2 < p2->size());
+
         GnuDiff::comparison comparisonInput;
         memset(&comparisonInput, 0, sizeof(comparisonInput));
         comparisonInput.parent = nullptr;
         comparisonInput.file[0].buffer = (*p1)[index1].getBuffer()->unicode() + (*p1)[index1].getOffset();                                                      //ptr to buffer
-        comparisonInput.file[0].buffered = ((*p1)[size1].getOffset() - 1); // size of buffer
+        comparisonInput.file[0].buffered = ((*p1)[index1 + size1 - 1].getOffset() + (*p1)[index1 + size1 - 1].size() - (*p1)[index1].getOffset()); // size of buffer
         comparisonInput.file[1].buffer = (*p2)[index2].getBuffer()->unicode() + (*p2)[index2].getOffset();                                                      //ptr to buffer
-        comparisonInput.file[1].buffered = ((*p2)[size2].getOffset() - 1); // size of buffer
+        comparisonInput.file[1].buffered = ((*p2)[index2 + size2 - 1].getOffset() + (*p2)[index2 + size2 - 1].size() - (*p2)[index2].getOffset()); // size of buffer
 
         gnuDiff.ignore_white_space = GnuDiff::IGNORE_ALL_SPACE; // I think nobody needs anything else ...
         gnuDiff.bIgnoreWhiteSpace = true;
@@ -754,7 +757,7 @@ void Diff3LineList::correctManualDiffAlignment(ManualDiffHelpList* pManualDiffHe
         e_SrcSelector wi = e_SrcSelector::None;
         for(; i3 != end(); ++i3)
         {
-            for(wi = e_SrcSelector::A; wi <= e_SrcSelector::Max; wi=nextSelector(wi))
+            for(wi = e_SrcSelector::A; wi != e_SrcSelector::Invalid; wi=nextSelector(wi))
             {
                 if(i3->getLineInFile(wi).isValid() && iMDHL->firstLine(wi) == i3->getLineInFile(wi))
                     break;
@@ -772,12 +775,12 @@ void Diff3LineList::correctManualDiffAlignment(ManualDiffHelpList* pManualDiffHe
             e_SrcSelector wi2 = e_SrcSelector::None;
             for(; i3 != end(); ++i3)
             {
-                for(wi2 = e_SrcSelector::A; wi2 <= e_SrcSelector::C; wi2 = nextSelector(wi2))
+                for(wi2 = e_SrcSelector::A; wi2 != e_SrcSelector::Invalid; wi2 = nextSelector(wi2))
                 {
                     if(wi != wi2 && i3->getLineInFile(wi2).isValid() && iMDHL->firstLine(wi2) == i3->getLineInFile(wi2))
                         break;
                 }
-                if(wi2 > e_SrcSelector::C)
+                if(wi2 == e_SrcSelector::Invalid)
                 { // Not yet found
                     // Move both others up
                     Diff3Line d3l;
@@ -1366,8 +1369,9 @@ bool Diff3Line::fineDiff(bool inBTextsTotalEqual, const e_SrcSelector selector,
     LineRef k1 = 0;
     LineRef k2 = 0;
     int maxSearchLength = 500;
-    bool bTextsTotalEqual = inBTextsTotalEqual, bIgnoreComments = eIgnoreFlags | IgnoreFlag::ignoreComments;
-    bool bIgnoreWhiteSpace = eIgnoreFlags | IgnoreFlag::ignoreWhiteSpace;
+    bool bTextsTotalEqual = inBTextsTotalEqual;
+    bool bIgnoreComments = eIgnoreFlags & IgnoreFlag::ignoreComments;
+    bool bIgnoreWhiteSpace = eIgnoreFlags & IgnoreFlag::ignoreWhiteSpace;
 
     Q_ASSERT(selector == e_SrcSelector::A || selector == e_SrcSelector::B || selector == e_SrcSelector::C);
 
